[Qa-jenkins-scm] [jenkins.debian.net] 02/06: reproducible: mv /var/lib/jenkins/stale_builds.txt /var/log/jenkins/stale_builds.log

Holger Levsen holger at moszumanska.debian.org
Sat Oct 10 00:32:37 UTC 2015


This is an automated email from the git hooks/post-receive script.

holger pushed a commit to branch master
in repository jenkins.debian.net.

commit 71a34d5dd32a6d53a631357cc5368b7b269daa64
Author: Holger Levsen <holger at layer-acht.org>
Date:   Sat Oct 10 02:01:53 2015 +0200

    reproducible: mv /var/lib/jenkins/stale_builds.txt /var/log/jenkins/stale_builds.log
---
 bin/reproducible_build.sh       | 8 ++++----
 bin/reproducible_maintenance.sh | 2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/bin/reproducible_maintenance.sh b/bin/reproducible_maintenance.sh
index 37b972a..88ea9df 100755
--- a/bin/reproducible_maintenance.sh
+++ b/bin/reproducible_maintenance.sh
@@ -329,7 +329,7 @@ fi
 # daily mails
 if [ "$HOSTNAME" = "$MAINNODE" ] && [ $(date -u +%H) -eq 0 ]  ; then
 	# once a day, send mail about builder problems
-	for PROBLEM in /var/lib/jenkins/stale_builds.txt /var/log/jenkins/reproducible-race-conditions.log /var/log/jenkins/reproducible-diskspace-issues.log ; do
+	for PROBLEM in /var/log/jenkins/stale_builds.log /var/log/jenkins/reproducible-race-conditions.log /var/log/jenkins/reproducible-diskspace-issues.log ; do
 		if [ -s $PROBLEM ] ; then
 			TMPFILE=$(mktemp --tmpdir=$TEMPDIR maintenance-XXXXXXXXXXXX)
 			mv $PROBLEM $TMPFILE

diff --git a/bin/reproducible_build.sh b/bin/reproducible_build.sh
index 7304828..a8d33be 100755
--- a/bin/reproducible_build.sh
+++ b/bin/reproducible_build.sh
@@ -407,11 +407,11 @@ choose_package() {
 	BAD_BUILDS=$(mktemp --tmpdir=$TMPDIR)
 	sqlite3 -init $INIT ${PACKAGES_DB} "SELECT package_id, date_build_started, builder FROM schedule WHERE builder LIKE '${BUILDER_PREFIX}%'" > $BAD_BUILDS
 	if [ -s "$BAD_BUILDS" ] ; then
-		# stale_builds.txt is mailed once a day by reproducible_maintenance.sh
-		echo "$(date -u) - stale builds found, cleaning db from these:" | tee -a /var/lib/jenkins/stale_builds.txt
-		cat $BAD_BUILDS | tee -a /var/lib/jenkins/stale_builds.txt
+		# stale_builds.log is mailed once a day by reproducible_maintenance.sh
+		echo "$(date -u) - stale builds found, cleaning db from these:" | tee -a /var/log/jenkins/stale_builds.log
+		cat $BAD_BUILDS | tee -a /var/log/jenkins/stale_builds.log
 		sqlite3 -init $INIT ${PACKAGES_DB} "UPDATE schedule SET date_build_started='', builder='' WHERE builder LIKE '${BUILDER_PREFIX}%'"
-		echo >> /var/lib/jenkins/stale_builds.txt
+		echo >> /var/log/jenkins/stale_builds.log
 	fi
 	rm -f $BAD_BUILDS
 	# mark build attempt, first test if none else marked a build attempt recently
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/qa/jenkins.debian.net.git



More information about the Qa-jenkins-scm mailing list